CachedAliceHttpCall_ class

CachedAliceHttpCall entity fields to define ObjectBox queries.

Constructors

CachedAliceHttpCall_()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

client QueryStringProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.client.
final
createdTime QueryDateNanoProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.createdTime.
final
duration QueryIntegerProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.duration.
final
endpoint QueryStringProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.endpoint.
final
errorRel QueryRelationToOne<CachedAliceHttpCall, CachedAliceHttpError>
See CachedAliceHttpCall.errorRel.
final
id QueryIntegerProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.id.
final
isDuplicate QueryBooleanProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.isDuplicate.
final
isReplay QueryBooleanProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.isReplay.
final
loading QueryBooleanProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.loading.
final
method QueryStringProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.method.
final
objectId QueryIntegerProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.objectId.
final
requestRel QueryRelationToOne<CachedAliceHttpCall, CachedAliceHttpRequest>
See CachedAliceHttpCall.requestRel.
final
responseRel QueryRelationToOne<CachedAliceHttpCall, CachedAliceHttpResponse>
See CachedAliceHttpCall.responseRel.
final
secure QueryBooleanProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.secure.
final
server QueryStringProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.server.
final
tag QueryStringProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.tag.
final
uri QueryStringProperty<CachedAliceHttpCall>
See CachedAliceHttpCall.uri.
final