CachedAliceHttpCall class
ObjectBox Entity of AliceHttpCall.
- Available extensions
- Annotations
-
- @Entity()
Constructors
Properties
- client ↔ String
-
getter/setter pair
- createdTime ↔ DateTime
-
getter/setter pair
- duration ↔ int
-
getter/setter pair
- endpoint ↔ String
-
getter/setter pair
- error ↔ AliceHttpError?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- isDuplicate ↔ bool
-
getter/setter pairinherited
- isReplay ↔ bool
-
getter/setter pair
- loading ↔ bool
-
getter/setter pair
- method ↔ String
-
getter/setter pair
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- request ↔ AliceHttpRequest?
-
getter/setter pair
- response ↔ AliceHttpResponse?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secure ↔ bool
-
getter/setter pair
- server ↔ String
-
getter/setter pair
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setter - tag ↔ String?
-
getter/setter pairinherited
- uri ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCached(
) → CachedAliceHttpCall -
Available on AliceHttpCall, provided by the AliceHttpCallExtension extension
ConvertsAliceHttpCallto CachedAliceHttpCall. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited